# srai-core


## Changleog

### 0.14.1
- changes to srai-release

### 0.14.0
- migrating to pyproject.toml

### 0.13.1
- added try load options to stores

### 0.13.0
- added dirstore options

### 0.12.0
- added in memory database
- added default release option